# Event Transforms (Pandas)

Efficient utility functions for wrangling DataFrames with event start/end times for rows, using built-in Pandas operations.

- ``coalesce_events`` combines overlapping events into single events